@@ -21,7 +21,7 @@
 
 */
 
-#include "ksysguardprocesslist.moc"
+
 #include "ksysguardprocesslist.h"
 
 #include "../config-ksysguard.h"
@@ -44,6 +44,8 @@
 #include <QToolTip>
 #include <QAbstractItemModel>
 #include <QtDBus>
+#include <QDialog>
+#include <QIcon>
 
 #include <signal.h> //For SIGTERM
 
@@ -51,11 +53,8 @@
 #include <KAuthAction>
 #include <KAuthActionReply>
 #include <KAuthObjectDecorator>
-#include <klocale.h>
+#include <klocalizedstring.h>
 #include <kmessagebox.h>
-#include <kdialog.h>
-#include <kicon.h>
-#include <kdebug.h>
 #include <KWindowSystem>
 
 #include "ReniceDlg.h"
@@ -165,10 +164,10 @@ struct KSysGuardProcessListPrivate {
         window = new QAction(i18n("Show Application Window"), q);
         resume = new QAction(i18n("Resume Stopped Process"), q);
         terminate = new QAction(i18np("End Process", "End Processes", 1), q);
-        terminate->setIcon(KIcon("process-stop"));
+        terminate->setIcon(QIcon::fromTheme("process-stop"));
         terminate->setShortcut(Qt::Key_Delete);
         kill = new QAction(i18np("Forcibly Kill Process", "Forcibly Kill Processes", 1), q);
-        kill->setIcon(KIcon("process-stop"));
+        kill->setIcon(QIcon::fromTheme("process-stop"));
         kill->setShortcut(Qt::SHIFT + Qt::Key_Delete);
 
         sigStop = new QAction(i18n("Suspend (STOP)"), q);
@@ -268,7 +267,7 @@ KSysGuardProcessList::KSysGuardProcessList(QWidget* parent, const QString &hostN
     d->mUi->treeView->setContextMenuPolicy(Qt::CustomContextMenu);
     connect(d->mUi->treeView, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(showProcessContextMenu(QPoint)));
 
-    d->mUi->treeView->header()->setClickable(true);
+    d->mUi->treeView->header()->setSectionsClickable(true);
     d->mUi->treeView->header()->setSortIndicatorShown(true);
     d->mUi->treeView->header()->setCascadingSectionResizes(false);
     connect(d->mUi->btnKillProcess, SIGNAL(clicked()), this, SLOT(killSelectedProcesses()));
@@ -302,7 +301,7 @@ KSysGuardProcessList::KSysGuardProcessList(QWidget* parent, const QString &hostN
     d->mUi->treeView->header()->resizeSection(ProcessModel::HeadingCPUUsage, d->mUi->treeView->header()->sectionSizeHint(ProcessModel::HeadingCPUUsage));
     d->mUi->treeView->header()->resizeSection(ProcessModel::HeadingMemory, d->mUi->treeView->header()->sectionSizeHint(ProcessModel::HeadingMemory));
     d->mUi->treeView->header()->resizeSection(ProcessModel::HeadingSharedMemory, d->mUi->treeView->header()->sectionSizeHint(ProcessModel::HeadingSharedMemory));
-    d->mUi->treeView->header()->setResizeMode(0, QHeaderView::Interactive);
+    d->mUi->treeView->header()->setSectionResizeMode(0, QHeaderView::Interactive);
     d->mUi->treeView->header()->setStretchLastSection(true);
 
     //Process names can have mixed case. Make the filter case insensitive.
@@ -334,7 +333,7 @@ KSysGuardProcessList::KSysGuardProcessList(QWidget* parent, const QString &hostN
 
     retranslateUi();
 
-    d->mUi->btnKillProcess->setIcon(KIcon("process-stop"));
+    d->mUi->btnKillProcess->setIcon(QIcon::fromTheme("process-stop"));
     d->mUi->btnKillProcess->setToolTip(i18n("<qt>End the selected process. Warning - you may lose unsaved work.<br>Right click on a process to send other signals.<br>See What's This for technical information.<br>To target a specific window to kill, press Ctrl+Alt+Esc at any time."));
 }
 
@@ -469,8 +468,6 @@ void KSysGuardProcessList::showProcessContextMenu(const QPoint &point) {
         KSysGuard::Process *parent_process = d->mModel.getProcess(process->parent_pid);
         if(parent_process) { //it should not be possible for this process to not exist, but check just incase
             QString parent_name = parent_process->name;
-            if(parent_name.size() > 20) //Elide the text if it is too long
-                parent_name = parent_process->name.left(15) + QString::fromUtf8("…");
             d->selectParent->setText(i18n("Jump to Parent Process (%1)", parent_name));
             d->mProcessContextMenu->addAction(d->selectParent);
         }
@@ -944,12 +941,12 @@ void KSysGuardProcessList::changeEvent( QEvent * event )
 }
 void KSysGuardProcessList::retranslateUi()
 {
-    d->mUi->cmbFilter->setItemIcon(ProcessFilter::AllProcesses, KIcon("view-process-all"));
-    d->mUi->cmbFilter->setItemIcon(ProcessFilter::AllProcessesInTreeForm, KIcon("view-process-all-tree"));
-    d->mUi->cmbFilter->setItemIcon(ProcessFilter::SystemProcesses, KIcon("view-process-system"));
-    d->mUi->cmbFilter->setItemIcon(ProcessFilter::UserProcesses, KIcon("view-process-users"));
-    d->mUi->cmbFilter->setItemIcon(ProcessFilter::OwnProcesses, KIcon("view-process-own"));
-    d->mUi->cmbFilter->setItemIcon(ProcessFilter::ProgramsOnly, KIcon("view-process-all"));
+    d->mUi->cmbFilter->setItemIcon(ProcessFilter::AllProcesses, QIcon::fromTheme("view-process-all"));
+    d->mUi->cmbFilter->setItemIcon(ProcessFilter::AllProcessesInTreeForm, QIcon::fromTheme("view-process-all-tree"));
+    d->mUi->cmbFilter->setItemIcon(ProcessFilter::SystemProcesses, QIcon::fromTheme("view-process-system"));
+    d->mUi->cmbFilter->setItemIcon(ProcessFilter::UserProcesses, QIcon::fromTheme("view-process-users"));
+    d->mUi->cmbFilter->setItemIcon(ProcessFilter::OwnProcesses, QIcon::fromTheme("view-process-own"));
+    d->mUi->cmbFilter->setItemIcon(ProcessFilter::ProgramsOnly, QIcon::fromTheme("view-process-all"));
 }
 
 void KSysGuardProcessList::updateList()
@@ -1282,8 +1279,6 @@ void KSysGuardProcessList::sendSignalToSelectedProcesses(int sig, bool confirm)
         if (!confirm)
             continue;
         QString name = d->mModel.getStringForProcess(process);
-        if(name.size() > 100)
-            name = name.left(95) + QString::fromUtf8("…");
         selectedAsStrings << name;
     }
 
